<?php
/**
 * Custom file of shortcode, add/change remove shortcode attribute
 */
add_filter('CleverBanner_shortcode_atts', function ($atts) {
    $atts['style'] = 'default';
    $atts['is_new'] = '';
    return $atts;
});
add_filter('CleverFeatureBox_shortcode_atts', function ($atts) {
    $atts['preset'] = 'default';
    return $atts;
});
add_action('vc_after_init', function () {
    vc_add_params('CleverBanner', array(
            array(
                "type" => 'dropdown',
                "heading" => esc_html__('Style', 'moleez'),
                "param_name" => 'style',
                "dependency" => array('element' => 'preset', 'value' => array('overlap')),
                'std' => 'default',
                "value" => array(
                    esc_html__('Default', 'moleez') => 'default',
                    esc_html__('Style 1', 'moleez') => 'style-1',
                    esc_html__('Style 2', 'moleez') => 'style-2',
                    esc_html__('Style 3', 'moleez') => 'style-3',
                ),
            ),
            array(
                'type' => 'checkbox',
                'heading' => esc_html__('Enable label New', 'moleez'),
                'param_name' => 'is_new',
                'std' => '',
                "dependency" => array('element' => 'style', 'value' => array('style-3')),
                'value' => array(esc_html__('Yes', 'moleez') => '1'),
            ),
        )
    );
    vc_add_params('CleverFeatureBox', array(
            array(
                "type" => 'dropdown',
                "heading" => esc_html__('Preset', 'moleez'),
                "param_name" => 'preset',
                "dependency" => array('element' => 'type', 'value' => array('icon')),
                'std' => 'default',
                "value" => array(
                    esc_html__('Default', 'moleez') => 'default',
                    esc_html__('Dark', 'moleez') => 'dark',
                    esc_html__('White', 'moleez') => 'white',
                ),
            ),
        )
    );
}, 10, 0);


function zoo_button_shortcode(array $atts, $content = null)
{
    $html = cvca_get_shortcode_view('button', $atts, $content);
    return $html;
}

/**
 * Register shortcode
 */
if (function_exists('clever_register_shortcode')) {
    clever_register_shortcode(
        'CleverButton',
        array(
            'link' => '',
            'type' => 'flat',
            'style' => 'dark',
            'align' => 'center',
            'icon' => '',
            'css_animation' => '',
            'css' => ''
        ),
        'zoo_button_shortcode',
        array(
            'name' => esc_html__('Clever Button', 'moleez'),
            'base' => 'CleverButton',
            'icon' => '',
            'category' => esc_html__('CleverSoft Elements', 'moleez'),
            'description' => esc_html__('Display Button With Custom style.', 'moleez'),
            'params' => array(
                array(
                    'type' => 'vc_link',
                    'heading' => esc_html__('Link', 'moleez'),
                    'value' => '#',
                    'param_name' => 'link',
                ),
                array(
                    'type' => 'iconpicker',
                    'heading' => esc_html__('Icon', 'moleez'),
                    'param_name' => 'icon',
                    'std' => '',
                    'value' => 'cs-font clever-icon-heart-1',
                    'settings' => array(
                        'emptyIcon' => false,
                        'type' => 'cleverfont',
                        'iconsPerPage' => 4000,
                    ),
                    'description' => esc_html__('Select icon from library.', 'moleez'),
                ),
                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__('Align', 'moleez'),
                    'value' => array(
                        esc_html__('Center', 'moleez') => 'center',
                        esc_html__('Left', 'moleez') => 'left',
                        esc_html__('Right', 'moleez') => 'right',
                    ),
                    'std' => 'center',
                    'param_name' => 'align',
                    'description' => esc_html__('Align button.', 'moleez'),
                ), array(
                    'type' => 'dropdown',
                    'heading' => esc_html__('Type', 'moleez'),
                    'value' => array(
                        esc_html__('Flat', 'moleez') => 'flat',
                        esc_html__('Outline', 'moleez') => 'outline',
                    ),
                    'std' => 'flat',
                    'param_name' => 'type',
                    'description' => esc_html__('Select type want use.', 'moleez'),
                ), array(
                    'type' => 'dropdown',
                    'heading' => esc_html__('Style', 'moleez'),
                    'value' => array(
                        esc_html__('Dark', 'moleez') => 'dark',
                        esc_html__('White', 'moleez') => 'white',
                    ),
                    'std' => 'dark',
                    'param_name' => 'style',
                    'description' => esc_html__('Select style want use.', 'moleez'),
                ),
                array(
                    'type' => 'animation_style',
                    'heading' => esc_html__('CSS Animation', 'moleez'),
                    'param_name' => 'css_animation',
                    'value' => '',
                ),
                array(
                    'type' => 'css_editor',
                    'counterup' => esc_html__('Css', 'moleez'),
                    'param_name' => 'css',
                    'group' => esc_html__('Design options', 'moleez'),
                )
            )
        )
    );
}