<?php
/**
 * Clever Products Deals Shortcode
 */
if (!function_exists('cvca_product_deal')) {
    function cvca_product_deal($atts, $content)
    {

        if (class_exists('WooCommerce')) {
            $atts = shortcode_atts(apply_filters('CleverProductDeal_shortcode_atts',array(
                'title' => '',
                'accent_color' => '',
                'border_after_width' => 90,
                'style-layout' =>'style-1',
                'min_height' => 715,
                'show_border'=> 1,
                'link'=> '',
                'orderby' => 'date',
                'order' => 'desc',
                'posts_per_page' => 6,
                'product_ids' => '',
                'filter_categories' => '',
                'custom_carousel'=> 1,
                'col_width_pc' => 4,
                'col_width_tablet' => 3,
                'col_width_mobile' => 2,
                'show_pag' => 1,
                'show_nav'=> 1,
                'autoplay'=> 1,
                'speed'=> 5000,
                'scroll'=> 1,
                'nav_position' => 'middle-nav',
                'element_custom_class' => '',
                'css' => '',
            )), $atts, 'CleverProductDeal');
            $html = cvca_get_shortcode_view( 'products-deals', $atts, $content );

            return $html;
        }
        return null;

    }
}
add_shortcode('CleverProductDeal', 'cvca_product_deal');

add_action('vc_before_init', 'cvca_product_deal_integrate_vc');

if (!function_exists('cvca_product_deal_integrate_vc')) {
    function cvca_product_deal_integrate_vc()
    {
        if (class_exists('WooCommerce')) {
            global $cvca_list_product;
            vc_map(
                array(
                    'name' => esc_html__('Clever Products Deals', 'cvca'),
                    'base' => 'CleverProductDeal',
                    'icon' => 'icon-wpb-woocommerce',
                    'category' => esc_html__('CleverSoft Elements', 'cvca'),
                    'description' => esc_html__('Show multiple products with layout carousel', 'cvca'),
                    'params' => array(
                        array(
                            'type' => 'textfield',
                            'heading' => esc_html__('Enter Title', 'cvca'),
                            'param_name' => 'title',
                            'description' => esc_html__('', 'cvca'),
                        ),
                        array(
                            'type' => 'colorpicker',
                            'heading' => esc_html__('Border Color', 'cvca'),
                            'param_name' => 'accent_color',
                            'description' => esc_html__('', 'cvca'),
                        ),
                        array(
                            'type' => 'textfield',
                            'heading' => esc_html__('Border After Width', 'cvca'),
                            'std' => 90,
                            'param_name' => 'border_after_width',
                            'description' => esc_html__('Add number for border after width.', 'cvca'),
                        ),
                        array(
                            'type' => 'dropdown',
                            'heading' => esc_html__('Style Layout', 'cvca'),
                            'std' =>'style-1',
                            'value' => array(
                                esc_html__('Style 1', 'cvca') => 'style-1',
                                esc_html__('Style 2', 'cvca') => 'style-2',
                            ),
                            "admin_label" => true,
                            'param_name' => 'style-layout',
                            'description' => esc_html__('Select layout style for display product', 'cvca'),
                        ),
                        array(
                            'type' => 'vc_link',
                            'heading' => esc_html__('Action Link and Text', 'cvca'),
                            'value' => '#',
                            'param_name' => 'link',
                            'description' => esc_html__('Enter text and link', 'cvca'),
                            'dependency' => Array('element' => 'style-layout', 'value' => array('style-2')),
                        ),
                        array(
                            'type' => 'textfield',
                            'heading' => esc_html__('Min height of block deal', 'cvca'),
                            'param_name' => 'min_height',
                            'std' => 715,
                            'description' => esc_html__('Enter number for show height of block deal', 'cvca'),
                            'dependency' => Array('element' => 'style-layout', 'value' => array('style-1')),
                        ),
                        array(
                            'type' => 'checkbox',
                            'heading' => esc_html__('Show border', 'cvca'),
                            'param_name' => 'show_border',
                            'std' => '1',
                            'value' => array(esc_html__('Allow', 'cvca') => 1),
                            'dependency' => Array('element' => 'style-layout', 'value' => array('style-1')),
                        ),
                        
                        array(
                            "type" => "cvca_multiselect2",
                            "heading" => esc_html__("Categories", 'cvca'),
                            "param_name" => "filter_categories",
                            "value" => $GLOBALS['cvca_product_cat_multi_select'],
                        ),
                        array(
                            'type' => 'autocomplete',
                            'heading' => esc_html__('Exclude Product IDs', 'cvca'),
                            'std' => '',
                            'param_name' => 'product_ids',
                            'description' => esc_html__('A comma-separated list of product you want to exclude.', 'cvca'),
                            'settings' => array(
                                'multiple' => true,
                                'sortable' => true,
                                'min_length' => 0,
                                'no_hide' => true,
                                'groups' => true, 
                                'unique_values' => true, 
                                'display_inline' => true, 
                                'values' => $cvca_list_product,
                            ),
                        ),
                        array(
                            'type' => 'dropdown',
                            'heading' => esc_html__('Order by', 'cvca'),
                            'value' => array(
                                esc_html__('Date', 'cvca') => 'date',
                                esc_html__('Menu order', 'cvca') => 'menu_order',
                                esc_html__('Title', 'cvca') => 'title',
                                esc_html__('Random', 'cvca') => 'rand',
                            ),
                            'std' => 'date',
                            'param_name' => 'orderby',
                        ),
                        array(
                            'type' => 'dropdown',
                            'heading' => esc_html__('Order', 'cvca'),
                            'value' => array(
                                esc_html__('DESC', 'cvca') => 'desc',
                                esc_html__('ASC', 'cvca') => 'asc',
                            ),
                            'std' => 'desc',
                            'param_name' => 'order',
                        ),
                        array(
                            'type' => 'textfield',
                            'heading' => esc_html__('Products per Pages', 'cvca'),
                            'value' => 6,
                            'param_name' => 'posts_per_page',
                            'description' => esc_html__('Products per Page showing', 'cvca'),
                        ),
                        
                        
                        array(
                            'type' => 'checkbox',
                            'heading' => esc_html__('Show Custom Carousel', 'cvca'),
                            'param_name' => 'custom_carousel',
                            'std' => 1,
                            'value' => array(esc_html__('Allow', 'cvca') => 1),
                            'description' => esc_html__('', 'cvca'),
                        ),
                        array(
                            'type' => 'dropdown',
                            'heading' => esc_html__('Carousel: Items PC', 'cvca'),
                            'dependency' => Array('element' => 'custom_carousel', 'value' => array('1')),
                            'param_name' => 'col_width_pc',
                            'std' => 4,
                            "value" => array(
                                esc_html__('1 columns', 'cvca') => 1,
                                esc_html__('2 columns', 'cvca') => 2,
                                esc_html__('3 columns', 'cvca') => 3,
                                esc_html__('4 columns', 'cvca') => 4,
                                esc_html__('5 columns', 'cvca') => 5,
                                esc_html__('6 columns', 'cvca') => 6,
                            ),
                        ),
                        array(
                            'type' => 'dropdown',
                            'heading' => esc_html__('Carousel: Items Tablet', 'cvca'),
                            'dependency' => Array('element' => 'custom_carousel', 'value' => array('1')),
                            'param_name' => 'col_width_tablet',
                            'std' => 3,
                            "value" => array(
                                esc_html__('1 columns', 'cvca') => 1,
                                esc_html__('2 columns', 'cvca') => 2,
                                esc_html__('3 columns', 'cvca') => 3,
                                esc_html__('4 columns', 'cvca') => 4,
                                esc_html__('5 columns', 'cvca') => 5,
                            ),
                        ),
                        array(
                            'type' => 'dropdown',
                            'heading' => esc_html__('Carousel: Items Mobile', 'cvca'),
                            'dependency' => Array('element' => 'custom_carousel', 'value' => array('1')),
                            'param_name' => 'col_width_mobile',
                            'std' => 2,
                            "value" => array(
                                esc_html__('1 column', 'cvca') => 1,
                                esc_html__('2 columns', 'cvca') => 2,
                                esc_html__('3 columns', 'cvca') => 3,
                            ),
                        ),
                        array(
                            'type' => 'checkbox',
                            'heading' => esc_html__('Carousel: Show Pagination', 'cvca'),
                            'param_name' => 'show_pag',
                            'std' => 1,
                            'dependency' => Array('element' => 'custom_carousel', 'value' => array('1')),
                            'value' => array(esc_html__('Allow', 'cvca') => 1),
                        ),
                        array(
                            'type' => 'checkbox',
                            'heading' => esc_html__('Carousel: Show Navigation', 'cvca'),
                            'param_name' => 'show_nav',
                            'std' => 1,
                            'dependency' => Array('element' => 'custom_carousel', 'value' => array('1')),
                            'value' => array(esc_html__('Allow', 'cvca') => 1),
                        ),
                        array(
                            'type' => 'checkbox',
                            'heading' => esc_html__('Carousel: Auto Play', 'cvca'),
                            'param_name' => 'autoplay',
                            'std' => 1,
                            'dependency' => Array('element' => 'custom_carousel', 'value' => array('1')),
                            'value' => array(esc_html__('Allow', 'cvca') => 1),
                        ),
                        array(
                            'type' => 'textfield',
                            'heading' => esc_html__('Carousel: Speed to Scroll', 'cvca'),
                            'std' => 5000,
                            'param_name' => 'speed',
                            'dependency' => Array('element' => 'custom_carousel', 'value' => array('1')),
                            'description' => esc_html__('', 'cvca'),
                        ),
                        array(
                            'type' => 'textfield',
                            'heading' => esc_html__('Carousel: Slide to Scroll', 'cvca'),
                            'std' => 1,
                            'param_name' => 'scroll',
                            'dependency' => Array('element' => 'custom_carousel', 'value' => array('1')),
                            'description' => esc_html__('', 'cvca'),
                        ),
                        array(
                            'type' => 'dropdown',
                            'heading' => esc_html__('Carousel: Navigation position', 'cvca'),
                            'param_name' => 'nav_position',
                            'std' => 'middle-nav',
                            'value' => array(
                                esc_html__('Middle', 'cvca') => 'middle-nav',
                            ),
                            'dependency' => Array('element' => 'custom_carousel', 'value' => array('1')),
                        ),

                        array(
                            'type' => 'textfield',
                            'heading' => esc_html__('Custom Class', 'cvca'),
                            'value' => '',
                            'param_name' => 'element_custom_class',
                            'description' => esc_html__('Style particular content element differently - add a class name and refer to it in custom CSS.', 'cvca'),
                        ),
                        array(
                            'type'       => 'css_editor',
                            'counterup'  => __( 'Css', 'cvca' ),
                            'param_name' => 'css',
                            'group'      => __( 'Design options', 'cvca' ),
                        ),
                    )
                )
            );
        }
    }
}