<?php
/**
 * Products List with Category Tabs Shortcode
 */
if (!function_exists('cvca_shortcode_products_list_category_tabs')) {
    function cvca_shortcode_products_list_category_tabs($atts, $content)
    {

        if (class_exists('WooCommerce')) {
            $atts = shortcode_atts(apply_filters('CleverProductsListCategoryTabs_shortcode_atts', array(
                'title' => '',
                'accent_color' => '',
                'border_after_width' => '90',
                'product_ids' => '',
                'posts_per_page' => 4,
                'filter' => 'cate',
                'filter_categories' => '',
                'default_category' => '',
                'asset_type' => '',
                'products_type' => 'list',
                'col_width' => 4,
                'col_width_medium' => 3,
                'col_width_small' => 2,
                'orderby' => 'date',
                'order' => 'desc',
                'element_custom_class' => '',
                'css' => '',
            )), $atts, 'CleverProductsListCategoryTabs');
            $html = cvca_get_shortcode_view('products-list-with-category-tabs', $atts, $content);

            return $html;
        }
        return null;

    }
}
add_shortcode('CleverProductsListCategoryTabs', 'cvca_shortcode_products_list_category_tabs');

add_action('vc_before_init', 'cvca_products_list_category_tabs_integrate_vc');

if (!function_exists('cvca_products_list_category_tabs_integrate_vc')) {
    function cvca_products_list_category_tabs_integrate_vc()
    {
        if (class_exists('WooCommerce')) {
            $asset_type = array(
                array('label' => esc_html__('New Arrivals', 'cvca'), 'value' => 'latest'),
                array('label' => esc_html__('Featured', 'cvca'), 'value' => 'featured'),
                array('label' => esc_html__('Onsale', 'cvca'), 'value' => 'onsale'),
                array('label' => esc_html__('Deal', 'cvca'), 'value' => 'deal'),
                array('label' => esc_html__('Best Seller', 'cvca'), 'value' => 'best-selling'),
                array('label' => esc_html__('Top Rate', 'cvca'), 'value' => 'toprate'),
            );
            $product_cats = $GLOBALS['cvca_list_product_cat'];
            global $cvca_list_product;
            vc_map(
                array(
                    'name' => esc_html__('Products Grid', 'cvca'),
                    'base' => 'CleverProductsListCategoryTabs',
                    'icon' => 'icon-wpb-woocommerce',
                    'category' => esc_html__('CleverSoft Elements', 'cvca'),
                    'description' => esc_html__('Show multiple products grid tabs.', 'cvca'),
                    'params' => array(
                        array(
                            'type' => 'textfield',
                            'heading' => esc_html__('Title', 'cvca'),
                            "admin_label" => true,
                            'param_name' => 'title',
                            'description' => esc_html__('', 'cvca'),
                        ),
                        array(
                            'type' => 'colorpicker',
                            'heading' => esc_html__('Border Color', 'cvca'),
                            "admin_label" => true,
                            'param_name' => 'accent_color',
                            'description' => esc_html__('', 'cvca'),
                        ),
                        array(
                            'type' => 'textfield',
                            'heading' => esc_html__('Border After Width', 'cvca'),
                            "admin_label" => true,
                            'std' => '90',
                            'param_name' => 'border_after_width',
                            'description' => esc_html__('Add number for border after width.', 'cvca'),
                        ),

                        array(
                            "type" => "cvca_multiselect2",
                            "heading" => esc_html__("Choose categories for show tabs", 'cvca'),
                            "param_name" => "filter_categories",
                            "value" => $GLOBALS['cvca_product_cat_multi_select'],
                        ),
                        array(
                            "type" => "dropdown",
                            "heading" => esc_html__("Choose default show category", 'cvca'),
                            "param_name" => "default_category",
                            "value" => $product_cats,
                        ),
                        array(
                            'type' => 'autocomplete',
                            'heading' => esc_html__('Exclude Product IDs', 'cvca'),
                            'std' => '',
                            'param_name' => 'product_ids',
                            'description' => esc_html__('A comma-separated list of product you want to exclude.', 'cvca'),
                            'settings' => array(
                                'multiple' => true,
                                'sortable' => true,
                                'min_length' => 0,
                                'no_hide' => true,
                                'groups' => true,
                                'unique_values' => true,
                                'display_inline' => true,
                                'values' => $cvca_list_product,
                            ),
                        ),
                        array(
                            'type' => 'dropdown',
                            'heading' => esc_html__('Asset type', 'cvca'),
                            'value' => $asset_type,
                            'std' => '',
                            'param_name' => 'asset_type',
                            'description' => esc_html__('Select asset type of products for show filter', 'cvca'),
                        ),
                        array(
                            'type' => 'textfield',
                            'heading' => esc_html__('Products per Page', 'cvca'),
                            'value' => 6,
                            "admin_label" => true,
                            'param_name' => 'posts_per_page',
                            'description' => esc_html__('Products per Page showing', 'cvca'),
                        ),
                        array(
                            'type' => 'dropdown',
                            'heading' => esc_html__('Order by', 'cvca'),
                            'value' => array(
                                esc_html__('Date', 'cvca') => 'date',
                                esc_html__('Menu order', 'cvca') => 'menu_order',
                                esc_html__('Title', 'cvca') => 'title',
                                esc_html__('Random', 'cvca') => 'rand',
                            ),
                            'std' => 'date',
                            'param_name' => 'orderby',
                        ),
                        array(
                            'type' => 'dropdown',
                            'heading' => esc_html__('Order', 'cvca'),
                            'value' => array(
                                esc_html__('DESC', 'cvca') => 'desc',
                                esc_html__('ASC', 'cvca') => 'asc',
                            ),
                            'std' => 'desc',
                            'param_name' => 'order',
                        ),

                        array(
                            'type' => 'dropdown',
                            'heading' => esc_html__('Column for row large device', 'cvca'),
                            'param_name' => 'col_width',
                            'std' => 4,
                            "value" => array(
                                esc_html__('1 columns', 'cvca') => 1,
                                esc_html__('2 columns', 'cvca') => 2,
                                esc_html__('3 columns', 'cvca') => 3,
                                esc_html__('4 columns', 'cvca') => 4,
                                esc_html__('5 columns', 'cvca') => 5,
                                esc_html__('6 columns', 'cvca') => 6,
                            ),
                        ),
                        array(
                            'type' => 'dropdown',
                            'heading' => esc_html__('Column for tablet', 'cvca'),
                            'param_name' => 'col_width_medium',
                            'std' => 3,
                            "value" => array(
                                esc_html__('1 columns', 'cvca') => 1,
                                esc_html__('2 columns', 'cvca') => 2,
                                esc_html__('3 columns', 'cvca') => 3,
                                esc_html__('4 columns', 'cvca') => 4,
                                esc_html__('5 columns', 'cvca') => 5,
                            ),
                        ),
                        array(
                            'type' => 'dropdown',
                            'heading' => esc_html__('Column for mobile', 'cvca'),
                            'param_name' => 'col_width_small',
                            'std' => 2,
                            "value" => array(
                                esc_html__('1 column', 'cvca') => 1,
                                esc_html__('2 columns', 'cvca') => 2,
                                esc_html__('3 columns', 'cvca') => 3,
                            ),
                        ),
                        array(
                            'type' => 'textfield',
                            'heading' => esc_html__('Custom Class', 'cvca'),
                            'value' => '',
                            'param_name' => 'element_custom_class',
                            'description' => esc_html__('Style particular content element differently - add a class name and refer to it in custom CSS.', 'cvca'),
                        ),
                        array(
                            'type' => 'css_editor',
                            'counterup' => __('Css', 'cvca'),
                            'param_name' => 'css',
                            'group' => __('Design options', 'cvca'),
                        ),
                    )
                )
            );
        }
    }
}