<?php
/**
 * CVCA Single Product Shortcode
 *
 * @internal    Used as a callback. PLEASE DO NOT RECALL THIS METHOD DIRECTLY!
 *
 * @param    array    $atts    Users' defined attributes in shortcode.
 *
 * @return    string    $html    Rendered shortcode content.
 */

if (!function_exists('cvca_single_product_shortcode')) {
    function cvca_single_product_shortcode( $atts, $content = null )
    {
        $atts = shortcode_atts(
            apply_filters('CleverSingleProduct_shortcode_atts', array(
                'product_id' => '',
                'css_animation' => 'none',
                'element_custom_class' => '',
                'css' => '',
            )),$atts, 'CleverSingleProduct');

        $html = cvca_get_shortcode_view( 'single-product', $atts, $content );

        return $html;
    }
    add_shortcode( 'CleverSingleProduct', 'cvca_single_product_shortcode' );
    add_action( 'vc_before_init', 'cvca_integrate_clever_single_product_shortcode_integrate_vc');
    function cvca_integrate_clever_single_product_shortcode_integrate_vc()
    {
        global $cvca_list_product;
        vc_map(array(
            'name' => esc_html__('Clever Single Product', 'cvca'),
            'base' => 'CleverSingleProduct',
            'icon' => 'data-is-container',
            'category' => esc_html__('CleverSoft Elements', 'cvca'),
            "description" => esc_html__("Display single product by specific id.", 'cvca'),
            "params" => array(
                array(
                    "type" => "autocomplete",
                    "heading" => esc_html__("Product ID", 'cvca'),
                    "description" => esc_html__("Enter product name", 'cvca'),
                    "param_name" => "product_id",
                    'settings' => array(
                        'multiple' => false,
                        'sortable' => true,
                        'min_length' => 0,
                        'no_hide' => true,
                        'groups' => true, 
                        'unique_values' => true, 
                        'display_inline' => true,
                        'values' => $cvca_list_product,
                    ),
                ),
                array(
                    "type" => 'cvca_animation_type',
                    "heading" => esc_html__("Animation Type", 'cvca'),
                    "param_name" => "css_animation",
                    "admin_label" => true,
                    'description' => esc_html__('Select animation type', 'cvca'),
                ),
                array(
                    'type' => 'textfield',
                    'heading' => esc_html__('Custom Class', 'cvca'),
                    'value' => '',
                    'param_name' => 'element_custom_class',
                    'description' => esc_html__('Style particular content element differently - add a class name and refer to it in custom CSS.', 'cvca'),
                ),
                array(
                    'type'       => 'css_editor',
                    'counterup'  => __( 'Css', 'cvca' ),
                    'param_name' => 'css',
                    'group'      => __( 'Design options', 'cvca' ),
                ),
            )
        ));
    }
}